@@ -2,7 +2,6 @@
 //!
 //! `Radio` component renders a radio group
 
-use crate::event::KeyCode;
 /**
  * MIT License
  *
@@ -26,6 +25,7 @@ use crate::event::KeyCode;
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
+use crate::event::KeyCode;
 use crate::props::{
     BordersProps, PropPayload, PropValue, Props, PropsBuilder, TextParts, TextSpan,
 };
@@ -127,7 +127,7 @@ impl RadioPropsBuilder {
         if let Some(props) = self.props.as_mut() {
             props.texts = TextParts::new(
                 label,
-                Some(options.into_iter().map(|x| TextSpan::from(x)).collect()), // Make textSpan from Strings);
+                Some(options.into_iter().map(TextSpan::from).collect()), // Make textSpan from Strings);
             )
         }
         self
